# -*- coding: utf-8 -*-
from typing import Dict


class CardBrand(object):

    def __init__(
        self
    ):
        self.brands = self._get_all_card_brands()

    def get_brand_code(
        self,
        brand   # type: str
    ):
        # type: (...) -> str

        brand = int(brand)
        return self.brands[brand]["sitef_brand_code"] if brand in self.brands.keys() else "99"

    @staticmethod
    def _get_all_card_brands():
        # type: (...) -> Dict[str, int]

        return {
            1: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ABN'},
            2: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ABRAPETITE'},
            3: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ACC-CARD'},
            4: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ACEITO'},
            5: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ACSP'},
            6: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'AGIPLAN'},
            7: {'sitef_brand_code': '10', 'sitef_brand_name': 'Alelo', 'cappta_brand_name': 'ALELO'},
            8: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'AMAZONIA CELULAR'},
            9: {'sitef_brand_code': '03', 'sitef_brand_name': 'American Express', 'cappta_brand_name': 'AMEX'},
            10: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ASCARD'},
            11: {'sitef_brand_code': '08', 'sitef_brand_name': 'Aura', 'cappta_brand_name': 'AURA'},
            12: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'AURA BERGAMAIS'},
            13: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'AURA FNAC'},
            14: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'AVISTA'},
            15: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANCRED'},
            16: {'sitef_brand_code': '11', 'sitef_brand_name': 'Banes Card', 'cappta_brand_name': 'BANESCARD'},
            17: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANESE CARD'},
            18: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANESTIK'},
            19: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANKCARD'},
            20: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANKTEC'},
            21: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANPARA'},
            22: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANQUET'},
            23: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANQUET SMART'},
            24: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANRICOMPRAS'},
            25: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANRISUL'},
            26: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANRISUL ALIMENTACAO'},
            27: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANRISUL COMBUSTIVEL'},
            28: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BASECARD'},
            29: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BEM'},
            30: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BIGCARD'},
            31: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BLACKHAWK'},
            32: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BNB CLUBE'},
            33: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BNDES'},
            34: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BONUS'},
            35: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BRADESCO'},
            36: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BRASILCARD'},
            37: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BRT FIXA'},
            38: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BRTELECOM'},
            39: {'sitef_brand_code': '09', 'sitef_brand_name': 'Cabal', 'cappta_brand_name': 'CABAL CRED'},
            40: {'sitef_brand_code': '09', 'sitef_brand_name': 'Cabal', 'cappta_brand_name': 'CABAL DEB'},
            41: {'sitef_brand_code': '09', 'sitef_brand_name': 'Cabal', 'cappta_brand_name': 'CABAL VALE'},
            42: {'sitef_brand_code': '12', 'sitef_brand_name': 'CalCard ', 'cappta_brand_name': 'CALCARD'},
            43: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CARDCO'},
            44: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CARTAO BRINQUEDO'},
            45: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CARTAO MAMAE'},
            46: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CARTAO NATAL'},
            47: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CB-BANCO DO BRASIL'},
            48: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CB-BRADESCO'},
            49: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CB-CITIBANK'},
            50: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CB-HSBC'},
            51: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CB-UNIBANCO'},
            52: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CELULAR'},
            53: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CHECKCHECK'},
            54: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CHEQUE ELETRONICO'},
            55: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CHEQUEPRE'},
            56: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CIELO'},
            57: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CLARO'},
            58: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CLARO OFF-LINE'},
            59: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'COLABORADOR'},
            60: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'COM VOCE'},
            61: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'COMPROCARD'},
            62: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CONSTRUCARD'},
            63: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CONVCARD'},
            64: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'COOPERCRED VALE'},
            65: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CPF'},
            66: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CREDI-SHOP'},
            67: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CREDITEM'},
            68: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CREDPAR'},
            69: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CREDSYSTEM'},
            70: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CTBC-CELULAR'},
            71: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CTBC-FIXO'},
            72: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'DACASA'},
            73: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'DIAMANTE'},
            74: {'sitef_brand_code': '05', 'sitef_brand_name': 'Diners Club', 'cappta_brand_name': 'DINERS'},
            75: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'DMCARD'},
            76: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ECXCARD'},
            77: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ELAVON'},
            78: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ELECTRON'},
            79: {'sitef_brand_code': '06', 'sitef_brand_name': 'Elo', 'cappta_brand_name': 'ELO CREDITO'},
            80: {'sitef_brand_code': '06', 'sitef_brand_name': 'Elo', 'cappta_brand_name': 'ELO DEBITO'},
            81: {'sitef_brand_code': '06', 'sitef_brand_name': 'Elo', 'cappta_brand_name': 'ELO VOUCHER'},
            82: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EMBRATEL'},
            83: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EMBRATEL LIVRE ONLINE'},
            84: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EPAY'},
            85: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EPAY SEGUROS'},
            86: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EPHARMA'},
            87: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EPHARMA BALCAO'},
            88: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EVANGELICO'},
            89: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FACIL'},
            90: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FACIL_LOSANGO'},
            91: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FAI'},
            92: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FALA FACIL'},
            93: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FANCARD'},
            94: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FARMASEG'},
            95: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FIC'},
            96: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FININVEST'},
            97: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FLEXMED'},
            98: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FORTBRASIL'},
            99: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FUNCIONAL CARD'},
            100: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GETNET'},
            101: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GIVEX'},
            102: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GOIASCARD'},
            103: {'sitef_brand_code': '15', 'sitef_brand_name': 'GoodCard', 'cappta_brand_name': 'GOODCARD'},
            104: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GOODMED'},
            105: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GOODVALE'},
            106: {'sitef_brand_code': '16', 'sitef_brand_name': 'GreenCard', 'cappta_brand_name': 'GREENCARD'},
            107: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GYNCARD'},
            108: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'HAPPY CARD'},
            109: {'sitef_brand_code': '07', 'sitef_brand_name': 'Hipercard', 'cappta_brand_name': 'HIPERCARD'},
            110: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'IBI'},
            111: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'IBICARD'},
            112: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'IBIPL'},
            113: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'INCOMM'},
            114: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'INFOCARDS'},
            115: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ITAU'},
            116: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ITAU-MOBILE'},
            117: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'J.C.B.'},
            118: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'JETPARCARD'},
            119: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'LEADER CARD'},
            120: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'LOJISTA'},
            121: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'LOSANGO'},
            122: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MAESTRO'},
            123: {'sitef_brand_code': '19', 'sitef_brand_name': 'Mais', 'cappta_brand_name': 'MAIS!'},
            124: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MARISA'},
            125: {'sitef_brand_code': '02', 'sitef_brand_name': 'Mastercard', 'cappta_brand_name': 'MASTERCARD'},
            126: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MAXICRED'},
            127: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MEDCHEQUE'},
            128: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MINASCRED'},
            129: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIALIMENTACAO'},
            130: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIALIMENTACAO BEN'},
            131: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIBENEFICIO'},
            132: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIBENEFICIOS'},
            133: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICASH'},
            134: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICESTABASICA'},
            135: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICHEQUE'},
            136: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICHEQUE ANTIGO'},
            137: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICHEQUE BEN'},
            138: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICOMBUSTIVEL'},
            139: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICULTURA'},
            140: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIEMPRESARIAL'},
            141: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIFARMA'},
            142: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIREFEICAO'},
            143: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MURY'},
            144: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NBC'},
            145: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NEUS'},
            146: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NEXTEL'},
            147: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NOKIA'},
            148: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NOVARTIS'},
            149: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NUTRICARD/BONUSCRED'},
            150: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NUTRICASH'},
            151: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'OBOÉCARD'},
            152: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'OI'},
            153: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'OI FIXA'},
            154: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'OI OFF'},
            155: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ORGCARD CRED'},
            156: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ORGCARD DEB'},
            157: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ORGCARD DVCS'},
            158: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros',
                  'cappta_brand_name': 'PAGUE CONTAS VISANET 4.1'},
            159: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PBMGOV'},
            160: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PERSONAL CARD'},
            161: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PHARMASYSTEM'},
            162: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PL FREECENTER'},
            163: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PL GETNET MASTER'},
            164: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PL GETNET VISA'},
            165: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PL MAGAZINE'},
            166: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PL TESOURA'},
            167: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PLANVALE'},
            168: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PLANVALE R'},
            169: {'sitef_brand_code': '21', 'sitef_brand_name': 'Policard', 'cappta_brand_name': 'POLICARD'},
            170: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PORTALCARD'},
            171: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'POUPCARD'},
            172: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PRATICARD'},
            173: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PREMIACAO'},
            174: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PREMIUM'},
            175: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PRESENTE'},
            176: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PRESTASERV'},
            177: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PREVSAUDE'},
            178: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PREZUNIC'},
            179: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros',
                  'cappta_brand_name': 'PRIVATE LABEL REDECARD'},
            180: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'QUALYCARD'},
            181: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'RAINBOW'},
            182: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros',
                  'cappta_brand_name': 'RANCHO CARD ALIMENTACAO'},
            183: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'RANCHO CARD CONVENIO'},
            184: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REC-FININVEST'},
            185: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDECARD'},
            186: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDESOFTNEX'},
            187: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDESOFTNEX CONV'},
            188: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REFEISUL'},
            189: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ROSSI'},
            190: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SAFRA AMANCO'},
            191: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SAPORE'},
            192: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SENFF'},
            193: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SERASA'},
            194: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SERCOMTEL-CELULAR'},
            195: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SERCOMTEL-FIXO'},
            196: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SICREDI CREDITO'},
            197: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SICREDI DEBITO'},
            198: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SIFRAGO'},
            199: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SIMCRED'},
            200: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SISCRED'},
            201: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SISTEMA'},
            202: {'sitef_brand_code': '23', 'sitef_brand_name': 'Sodexo', 'cappta_brand_name': 'SODEXO ALIMENTACAO'},
            203: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SODEXO REFEICAO'},
            204: {'sitef_brand_code': '23', 'sitef_brand_name': 'Sodexo', 'cappta_brand_name': 'SOLLO'},
            205: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SOLUCARD'},
            206: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SOMAR'},
            207: {'sitef_brand_code': '04', 'sitef_brand_name': 'Sorocred', 'cappta_brand_name': 'SOROCRED'},
            208: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SOROCRED CREDITO'},
            209: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'STAFFCARD'},
            210: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SUPER BONUS'},
            211: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SUPERCARD'},
            212: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SYSDATA'},
            213: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TECBAN'},
            214: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELECHEQUE'},
            215: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELEFONICA'},
            216: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELEFONIC-FAMILIA'},
            217: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELEMAR'},
            218: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELEMIG'},
            219: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELENET'},
            220: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELESP-SUPER 15'},
            221: {'sitef_brand_code': '27', 'sitef_brand_name': 'Ticket', 'cappta_brand_name': 'TICKET ALIMENTAÇÃO'},
            222: {'sitef_brand_code': '27', 'sitef_brand_name': 'Ticket', 'cappta_brand_name': 'TICKET CAR'},
            223: {'sitef_brand_code': '27', 'sitef_brand_name': 'Ticket', 'cappta_brand_name': 'TICKET RESTAURANTE'},
            224: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TIM'},
            225: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TIM ON-LINE'},
            226: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TIPCARD'},
            227: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TMS'},
            228: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TOKORO'},
            229: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TOPCARD'},
            230: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TOPPREMIUM'},
            231: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TRANSCHECK'},
            232: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TRICARD'},
            233: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TRNCENTRE'},
            234: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'UNIK'},
            235: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'UNNISA'},
            236: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'USECRED'},
            237: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VAELETRONICO'},
            238: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALE MAIS'},
            239: {'sitef_brand_code': '24', 'sitef_brand_name': 'ValeCard', 'cappta_brand_name': 'VALECARD'},
            240: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALECASH'},
            241: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALEFROTA'},
            242: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALEGAS'},
            243: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALESHOP'},
            244: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALETIK'},
            245: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VEGAS CARD'},
            246: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VERDECARD'},
            247: {'sitef_brand_code': '25', 'sitef_brand_name': 'Verocheque', 'cappta_brand_name': 'VEROCHEQUE'},
            248: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VIA FINANCEIRA'},
            249: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VIDALINK'},
            250: {'sitef_brand_code': '01', 'sitef_brand_name': 'Visa', 'cappta_brand_name': 'VISA'},
            251: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VIVO'},
            252: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VIVO OFF-LINE'},
            253: {'sitef_brand_code': '26', 'sitef_brand_name': 'VR', 'cappta_brand_name': 'VR ALIMENTACAO'},
            254: {'sitef_brand_code': '26', 'sitef_brand_name': 'VR', 'cappta_brand_name': 'VR AUTO'},
            255: {'sitef_brand_code': '26', 'sitef_brand_name': 'VR', 'cappta_brand_name': 'VR CULTURA'},
            256: {'sitef_brand_code': '26', 'sitef_brand_name': 'VR', 'cappta_brand_name': 'VR REFEICAO'},
            257: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ZOGBI'},
            259: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SODEXO COMBUSTÍVEL'},
            260: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALGORIX'},
            261: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALGORIX_S'},
            262: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SAVS'},
            263: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VEROCHEQUE CREDITO'},
            265: {'sitef_brand_code': '13', 'sitef_brand_name': 'Credz', 'cappta_brand_name': 'CREDZ'},
            266: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ESPLANADA'},
            267: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SODEXO'},
            268: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ELO REFEICAO'},
            269: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ELO ALIMENTACAO'},
            270: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PBM PADRAO'},
            271: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CIELO AUTO'},
            273: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BIGCARD DEB'},
            276: {'sitef_brand_code': '27', 'sitef_brand_name': 'Ticket', 'cappta_brand_name': 'TICKET ALIMENTACAO'},
            277: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALELO REFEICAO'},
            278: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALELO ALIMENTACAO'},
            279: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BAHAMAS CRED'},
            280: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BAHAMAS ALIM'},
            281: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANESCARD DEBITO'},
            283: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FLEETCOR'},
            284: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MAXXCARD'},
            285: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'METTACARD'},
            286: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDE CRED'},
            287: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDE DEB'},
            288: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDE VOUCHER'},
            289: {'sitef_brand_code': '17', 'sitef_brand_name': 'Hiper', 'cappta_brand_name': 'HIPER DEB'},
            290: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALGORIX-VOUCHER'},
            291: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CREDIALIMENTACAO'},
            292: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VISA VALE'},
            293: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'UAI CARD'},
            294: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDEMED'},
            295: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PARACATUCARD'},
            296: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALECARD DEB'},
            297: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIPLUS'},
            298: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'POLICARD CREDITO'},
            299: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'POLICARD DEBITO'},
            300: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'POLICARD ALIMENTACAO'},
            301: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'POLICARD REFEICAO'},
            302: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GOODCARD ALIMENTACAO'},
            303: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GOODCARD REFEICAO'},
            304: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALELO REFEIÇÃO'},
            305: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALELO ALIMENTAÇÃO'},
            306: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VEGAS CARD'},
            307: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VEGAS CARD'},
            308: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALLE EXPRESS'}
        }
