class FinishPaymentData(object):
    def __init__(self, pos_id, order_id, fiscal_date, fiscal_time, status):
        self.pos_id = int(pos_id)
        self.order_id = int(order_id)
        self.fiscal_date = fiscal_date
        self.fiscal_time = fiscal_time
        self.status = int(status)

    def __repr__(self):
        return 'FinishPaymentData(pos_id={}, order_id={}, fiscal_date="{}", fiscal_time="{}", status={})'.format(
            self.pos_id, self.order_id, self.fiscal_date, self.fiscal_time, self.status
        )

    def __str__(self):
        return self.__repr__()
