# -*- coding: utf-8 -*-

from _CapptaProcessor import CapptaProcessor


class CapptaCreditPaymentProcessor(object):
    def __init__(self, message_bus, dialog_manager, config, logger):
        self.cappta_processor = CapptaProcessor(message_bus, dialog_manager, config, logger)

    def connection_status(self, test_connection_data):
        return self.cappta_processor.connection_status(test_connection_data)

    def add_payment(self, start_payment_data):
        return self.cappta_processor.add_payment(start_payment_data)

    def cancel_payment(self):
        return self.cappta_processor.cancel_payment()

    def finish_payment(self, finish_payment_data):
        self.cappta_processor.finish_payment(finish_payment_data)

    def get_name(self):
        return self.cappta_processor.get_name()

    def stop(self):
        self.cappta_processor.stop()
