class StartPaymentData(object):
    def __init__(self, pos_id, order_id, session_id, operator, tender_type, amount, fiscal_date, fiscal_time,
                 tender_seq):
        self.pos_id = int(pos_id)
        self.order_id = int(order_id)
        self.session_id = session_id
        self.operator = int(operator)
        self.tender_type = int(tender_type)
        self.amount = amount
        self.fiscal_date = fiscal_date
        self.fiscal_time = fiscal_time
        self.tender_seq = int(tender_seq)

    def __repr__(self):
        return 'StartPaymentData(pos_id={}, ' \
               'order_id={}, ' \
               'session_id={}' \
               'operator={}, ' \
               'tender_type={}, ' \
               'amount="{}", ' \
               'fiscal_date="{}", ' \
               'fiscal_time="{}", ' \
               'tender_seq={})'.format(
                   self.pos_id, self.order_id, self.session_id, self.operator, self.tender_type, self.amount,
                   self.fiscal_date, self.fiscal_time, self.tender_seq
               )

    def __str__(self):
        return self.__repr__()
